@@ -27,7 +27,7 @@ class EnumMeta(Protocol):
     def __iter__(self) -> Iterator[Enum]: ...
 
 
-def make_enum_type(enum_cls: EnumMeta) -> click.Choice:
+def make_enum_type(enum_cls: EnumMeta) -> click.Choice[Enum]:
     return click.Choice([variant.value for variant in enum_cls], case_sensitive=False)
 
 
